@@ -54,7 +54,7 @@ class JanelaMain:
 
     def __show_logo(self):
 
-        logo = tk.PhotoImage(file="pySEP/pySEP_logo.png")
+        logo = tk.PhotoImage(file="pySEP/images/pySEP_logo.png")
 
         self.__label_logo = tk.Label(
             master=self.__janela,
@@ -68,7 +68,7 @@ class JanelaMain:
     def set_janela(janela_main):
         janela_main.title("pySEP    -    Python em Sistemas Elétricos de Potência!")
         janela_main.geometry("1280x720+100+100")
-        janela_main.wm_iconbitmap("pySEP/logo_pySEP.ico")
+        janela_main.wm_iconbitmap("pySEP/images/logo_pySEP.ico")
         janela_main["bg"] = "light goldenrod"
         janela_main["bd"] = 5
 
@@ -127,7 +127,7 @@ class JanelaMain:
         config_relatorio = tk.Toplevel()
         config_relatorio.title("Relatório Final do Fluxo de Potência")
         config_relatorio.geometry("460x250")
-        config_relatorio.wm_iconbitmap("pySEP/logo_pySEP.ico")
+        config_relatorio.wm_iconbitmap("pySEP/images/logo_pySEP.ico")
         config_relatorio["bg"] = "light goldenrod"
 
         frame_relatorio = tk.LabelFrame(
@@ -268,7 +268,7 @@ class JanelaMain:
         config_fluxo = tk.Toplevel()
         config_fluxo.title("Calcular Fluxo de Potência")
         config_fluxo.geometry("460x250")
-        config_fluxo.wm_iconbitmap("pySEP/logo_pySEP.ico")
+        config_fluxo.wm_iconbitmap("pySEP/images/logo_pySEP.ico")
         config_fluxo["bg"] = "light goldenrod"
 
         frame_config = tk.LabelFrame(
@@ -457,7 +457,7 @@ class JanelaMain:
         s_base = tk.Toplevel(master=self.__janela)
         s_base.title("\tBem-vindo ao pySEP!!\t")
         s_base.geometry("500x175+500+500")
-        s_base.wm_iconbitmap("pySEP/logo_pySEP.ico")
+        s_base.wm_iconbitmap("pySEP/images/logo_pySEP.ico")
         s_base["bg"] = "light goldenrod"
 
         label_s_base = tk.Label(
@@ -508,7 +508,7 @@ class JanelaMain:
         erro = tk.Toplevel()
         erro.title("\tERRO!!\t")
         erro.geometry("400x250")
-        erro.wm_iconbitmap("pySEP/logo_pySEP.ico")
+        erro.wm_iconbitmap("pySEP/images/logo_pySEP.ico")
         erro["bg"] = "red"
 
         label_erro = tk.Label(
@@ -527,7 +527,7 @@ class JanelaMain:
         config_bar = tk.Toplevel()
         config_bar.title("Configurações da barra " + str(self.__info_basic['nums'].get('barras')))
         config_bar.geometry("1000x275")
-        config_bar.wm_iconbitmap("pySEP/logo_pySEP.ico")
+        config_bar.wm_iconbitmap("pySEP/images/logo_pySEP.ico")
         config_bar["bg"] = "light goldenrod"
 
         frame_config = tk.LabelFrame(
@@ -817,7 +817,7 @@ class JanelaMain:
         config_lin = tk.Toplevel()
         config_lin.title("Configurações de linha ")
         config_lin.geometry("815x275")
-        config_lin.wm_iconbitmap("pySEP/logo_pySEP.ico")
+        config_lin.wm_iconbitmap("pySEP/images/logo_pySEP.ico")
         config_lin["bg"] = "light goldenrod"
 
         frame_config = tk.LabelFrame(
